==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/block/custom/StickCrossBlock.java <==
package net.tlotd.block.custom;

import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2738;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_2754;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import java.util.Objects;

public class StickCrossBlock extends class_2248 {

    public static final class_2754<class_2738> FACE = class_2741.field_12555;
    public static final class_2753 FACING = class_2741.field_12525;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;
    public static final class_2746 FLIPPED = class_2746.method_11825("flipped");

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        boolean flipped = false;
        if (Objects.requireNonNull(ctx.method_8036()).method_5715()) {
            flipped = true;
        }
        for (class_2350 direction : ctx.method_7718()) {
            class_2680 blockState = direction.method_10166() == class_2350.class_2351.field_11052 ? this.method_9564().method_11657(FACE, direction == class_2350.field_11036 ? class_2738.field_12473 : class_2738.field_12475).method_11657(FACING, ctx.method_8042()).method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910)).method_11657(FLIPPED, flipped) : this.method_9564().method_11657(FACE, class_2738.field_12471).method_11657(FACING, direction).method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910)).method_11657(FLIPPED, flipped);
            if (!blockState.method_26184(ctx.method_8045(), ctx.method_8037())) continue;
            return blockState;
        }
        return null;
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return super.method_9559(state, direction, neighborState, world, pos, neighborPos);
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACE, FACING, WATERLOGGED, FLIPPED);
    }

    public StickCrossBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(FACE, class_2738.field_12471).method_11657(FACING, class_2350.field_11043).method_11657(WATERLOGGED, false).method_11657(FLIPPED, false));
    }

    public static final class_265 NORTH_SHAPE = class_2248.method_9541(3, 1, 0, 13, 15, 2);
    public static final class_265 EAST_SHAPE = class_2248.method_9541(14, 1, 3, 16, 15, 13);
    public static final class_265 SOUTH_SHAPE = class_2248.method_9541(3, 1, 14, 13, 15, 16);
    public static final class_265 WEST_SHAPE = class_2248.method_9541(0, 1, 3, 2, 15, 13);
    public static final class_265 DOWN_SHAPE = class_2248.method_9541(1, 0, 3, 15, 2, 13);
    public static final class_265 DOWN_SHAPE_2 = class_2248.method_9541(3, 0, 1, 13, 2, 15);
    public static final class_265 UP_SHAPE = class_2248.method_9541(1, 14, 3, 15, 16, 13);
    public static final class_265 UP_SHAPE_2 = class_2248.method_9541(3, 14, 1, 13, 16, 15);

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        switch (state.method_11654(FACE)) {
            case field_12475: {
                switch (state.method_11654(FACING).method_10166()) {
                    case field_11048: {
                        return DOWN_SHAPE;
                    }
                }
                return DOWN_SHAPE_2;
            }
            case field_12471: {
                switch (state.method_11654(FACING)) {
                    case field_11034: {
                        return EAST_SHAPE;
                    }
                    case field_11039: {
                        return WEST_SHAPE;
                    }
                    case field_11035: {
                        return SOUTH_SHAPE;
                    }
                }
                return NORTH_SHAPE;
            }
        }
        switch (state.method_11654(FACING).method_10166()) {
            case field_11048: {
                return UP_SHAPE;
            }
        }
        return UP_SHAPE_2;
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/block/custom/StickCrossBlock.java <==
package net.tlotd.block.custom;

import net.minecraft.block.*;
import net.minecraft.class_124;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2464;
import net.minecraft.class_2470;
import net.minecraft.class_2561;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2738;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_2754;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Objects;

public class StickCrossBlock extends class_2248 {

    public static final class_2754<class_2738> FACE = class_2741.field_12555;
    public static final class_2753 FACING = class_2741.field_12525;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;
    public static final class_2746 FLIPPED = class_2746.method_11825("flipped");

    @Override
    public class_2680 method_9605(class_1750 ctx) {
        boolean flipped = false;
        if (Objects.requireNonNull(ctx.method_8036()).method_5715()) {
            flipped = true;
        }
        for (class_2350 direction : ctx.method_7718()) {
            class_2680 blockState = direction.method_10166() == class_2350.class_2351.field_11052 ? this.method_9564().method_11657(FACE, direction == class_2350.field_11036 ? class_2738.field_12473 : class_2738.field_12475).method_11657(FACING, ctx.method_8042()).method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910)).method_11657(FLIPPED, flipped) : this.method_9564().method_11657(FACE, class_2738.field_12471).method_11657(FACING, direction).method_11657(WATERLOGGED, ctx.method_8045().method_8316(ctx.method_8037()).method_39360(class_3612.field_15910)).method_11657(FLIPPED, flipped);
            if (!blockState.method_26184(ctx.method_8045(), ctx.method_8037())) continue;
            return blockState;
        }
        return null;
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return state.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(state);
    }

    @Override
    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        if (state.method_11654(WATERLOGGED)) {
            world.method_39281(pos, class_3612.field_15910, class_3612.field_15910.method_15789(world));
        }

        return super.method_9559(state, direction, neighborState, world, pos, neighborPos);
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACE, FACING, WATERLOGGED, FLIPPED);
    }

    public StickCrossBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(FACE, class_2738.field_12471).method_11657(FACING, class_2350.field_11043).method_11657(WATERLOGGED, false).method_11657(FLIPPED, false));
    }

    public static final class_265 NORTH_SHAPE = class_2248.method_9541(3, 1, 0, 13, 15, 2);
    public static final class_265 EAST_SHAPE = class_2248.method_9541(14, 1, 3, 16, 15, 13);
    public static final class_265 SOUTH_SHAPE = class_2248.method_9541(3, 1, 14, 13, 15, 16);
    public static final class_265 WEST_SHAPE = class_2248.method_9541(0, 1, 3, 2, 15, 13);
    public static final class_265 DOWN_SHAPE = class_2248.method_9541(1, 0, 3, 15, 2, 13);
    public static final class_265 DOWN_SHAPE_2 = class_2248.method_9541(3, 0, 1, 13, 2, 15);
    public static final class_265 UP_SHAPE = class_2248.method_9541(1, 14, 3, 15, 16, 13);
    public static final class_265 UP_SHAPE_2 = class_2248.method_9541(3, 14, 1, 13, 16, 15);

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        switch (state.method_11654(FACE)) {
            case field_12475: {
                switch (state.method_11654(FACING).method_10166()) {
                    case field_11048: {
                        return DOWN_SHAPE;
                    }
                }
                return DOWN_SHAPE_2;
            }
            case field_12471: {
                switch (state.method_11654(FACING)) {
                    case field_11034: {
                        return EAST_SHAPE;
                    }
                    case field_11039: {
                        return WEST_SHAPE;
                    }
                    case field_11035: {
                        return SOUTH_SHAPE;
                    }
                }
                return NORTH_SHAPE;
            }
        }
        switch (state.method_11654(FACING).method_10166()) {
            case field_11048: {
                return UP_SHAPE;
            }
        }
        return UP_SHAPE_2;
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    @Override
    public void method_9568(class_1799 stack, @Nullable class_1922 world, List<class_2561> tooltip, class_1836 options) {
        tooltip.add(class_2561.method_43471("item.tlotd.desc_divine").method_27692(class_124.field_1054));
        super.method_9568(stack, world, tooltip, options);
    }
}
